/*
	This file is part of Warzone 2100.
	Copyright (C) 2020  Warzone 2100 Project

	Warzone 2100 is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	Warzone 2100 is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Warzone 2100; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/

#ifndef __INCLUDED_SRC_URL_HELPERS_H__
#define __INCLUDED_SRC_URL_HELPERS_H__

#include <string>
#include <vector>

bool openURLInBrowser(char const *url);
std::string urlEncode(const char* urlFragment);
bool urlHasAcceptableProtocol(char const *url);

bool openFolderInDefaultFileManager(const char* path);

#if defined(WZ_OS_WIN)
bool win_utf8ToUtf16(const char* str, std::vector<wchar_t>& outputWStr);
#endif

#endif // __INCLUDED_SRC_URL_HELPERS_H__
